
module NumPlot
  # The class handling options on gnuplot command.
  # @!visibility private
  class Option
    def initialize(name, converter, aliases)
      @name = name
      @converter = converter
      @aliases = aliases
    end
    
    def plot_arg(h)
      ([@name] + @aliases).each do |key|
        if h.has_key? (key)
          return " #{@name} #{@converter[h[key]]}"
        end
      end
      
      ""
    end
    
    def self.[](name, *aliases)
      new(name, proc{|x| x }, aliases)
    end
  end

  # The class handling color options on gnuplot command.
  # @!visibility private
  class ColorOption < Option
    def self.[](name, *aliases)
      new(name, Conversion.method(:convert_color), aliases)
    end
  end

  # The class handling font options on gnuplot command.
  # @!visibility private
  class FontOption < Option
    def self.[](name, *aliases)
      new(name, Conversion.method(:convert_font), aliases)
    end
  end

  # The class handling on/off options on gnuplot command.
  # @!visibility private
  class BoolOption
    def initialize(name, *aliases)
      @name = name; @aliases = aliases
    end
    
    def plot_arg(h)
      ([@name] + @aliases).each do |key|
        return " #{@name}" if h.has_key?(key)
      end
      
      ""
    end
    
    class << self
      alias [] new
    end
  end

  # The class handling XXX/noXXX options on gnuplot command
  # @!visibility private
  class YesNoOption
    def initialize(name)
      @name = name
      @no_name = "no#{name}".intern
    end

    def plot_arg(h)
      return " #{@name}" if h.has_key?(@name) && h[@name]
      return " #{@name}" if h.has_key?(@no_name) && !h[@no_name]
      return " #{@no_name}" if h.has_key?(@no_name) && h[@no_name]
      return " #{@no_name}" if h.has_key?(@name) && !h[@name]
      ""
    end

    class << self
      alias [] new
    end
  end
end
